@@ -15,19 +15,20 @@ def home(warehouse):
         warehouse['home'] = response
     return response
 
-def _post(section_name, eventtarget):
+def _post(section_name, data_func):
     def f(warehouse, session, _id):
         key = (section_name, _id)
         if key in warehouse:
             response = warehouse[key]
         else:
             cookies, publickeytoken, viewstate, eventvalidation = session
-            data = p.data(publickeytoken, viewstate, eventvalidation, eventtarget, _id)
+            data = data_func(publickeytoken, viewstate, eventvalidation, _id)
+            files = [(key, ('', str(value))) for key, value in data]
             randomsleep()
-            response = requests.post(p.url(), headers = p.headers(ua()), data = data, cookies = cookies)
+            response = requests.post(p.url(), headers = p.headers(ua()), files = files, cookies = cookies)
             warehouse[key] = response
         return response
     return f
 
-street = _post('street', 'dnn$ctr1381$ViewPIRPS$lstboxStreets')
-house  = _post('house',  'dnn$ctr1381$ViewPIRPS$lstboxAddresses')
+street = _post('street', p.street_data)
+house  = _post('house',  p.house_data)
